"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const SecondayEntityManagerHelper_1 = require("./SecondayEntityManagerHelper");
class AntSqlSecondaryEntityManager {
    constructor(model, dbConnection) {
        this._dbConnection = dbConnection;
        this._helper = new SecondayEntityManagerHelper_1.SecondaryEntityManagerHelper(model, dbConnection);
        this._model = model;
    }
    get model() {
        return this._model;
    }
    delete(id) {
        return this
            ._dbConnection
            .from(this.model.tableName)
            .where(this.model.id, id)
            .del();
    }
    getById(id) {
        return new Promise((resolve, reject) => {
            this
                ._dbConnection
                .from(this.model.tableName)
                .where(this.model.id, id)
                .then((results) => {
                if (0 === results.length) {
                    resolve(null);
                }
                else {
                    resolve(results[0]);
                }
            }).catch(reject);
        });
    }
    getByIds(ids) {
        return new Promise((resolve, reject) => {
            this
                ._dbConnection
                .from(this.model.tableName)
                .whereIn(this.model.id, ids)
                .then(resolve)
                .catch(reject);
        });
    }
    getByIdsOrderedAsc(ids) {
        const ascOrder = 'ASC';
        return new Promise((resolve, reject) => {
            this
                ._dbConnection
                .from(this.model.tableName)
                .whereIn(this.model.id, ids)
                .orderBy(this.model.id, ascOrder)
                .then(resolve)
                .catch(reject);
        });
    }
    insert(entity) {
        let insertionPromise = this
            ._dbConnection
            .insert([this._helper.buildKnexObject(this.model, entity)])
            .into(this.model.tableName);
        const autoGeneratedColumn = this.model.getAutoGeneratedColumn();
        if (null !== autoGeneratedColumn) {
            insertionPromise = insertionPromise
                .returning(autoGeneratedColumn.sqlName)
                .then((value) => {
                entity[autoGeneratedColumn.entityAlias] = value[0];
            });
        }
        return insertionPromise;
    }
    mDelete(ids) {
        if (0 === ids.length) {
            return new Promise((resolve) => resolve());
        }
        return this
            ._dbConnection
            .from(this.model.tableName)
            .whereIn(this.model.id, ids)
            .del();
    }
    mInsert(entities) {
        if (0 === entities.length) {
            return new Promise((resolve) => resolve());
        }
        let insertionPromise = this
            ._dbConnection
            .insert(entities.map((entity) => this._helper.buildKnexObject(this.model, entity)))
            .into((this.model.tableName));
        const autoGeneratedColumn = this.model.getAutoGeneratedColumn();
        if (null != autoGeneratedColumn) {
            insertionPromise = insertionPromise
                .returning(autoGeneratedColumn.sqlName)
                .then((values) => {
                for (let i = 0; i < entities.length; ++i) {
                    if (null != values[i]) {
                        entities[i][autoGeneratedColumn.entityAlias] = values[i];
                    }
                }
            });
        }
        return insertionPromise;
    }
    mUpdate(entities) {
        if (0 === entities.length) {
            return new Promise((resolve) => resolve());
        }
        return this
            ._dbConnection
            .transaction((transaction) => {
            const queries = new Array();
            for (const entity of entities) {
                queries.push(this
                    ._dbConnection(this.model.tableName)
                    .where(this.model.id, entity[this.model.id])
                    .update(this._helper.buildKnexObject(this.model, entity))
                    .transacting(transaction));
            }
            Promise.all(queries)
                .then(() => transaction.commit())
                .catch(transaction.rollback);
        });
    }
    update(entity) {
        return this
            ._dbConnection(this.model.tableName)
            .where(this.model.id, entity[this.model.id])
            .update(this._helper.buildKnexObject(this.model, entity));
    }
}
exports.AntSqlSecondaryEntityManager = AntSqlSecondaryEntityManager;
//# sourceMappingURL=AntSqlSecondaryEntityManager.js.map