"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class SecondaryEntityManagerHelper {
    constructor(model, dbConnection) {
        this._dbConnection = dbConnection;
        this._model = model;
    }
    buildKnexObject(model, entity) {
        const updateObject = {};
        for (const [, columnData] of model.columns) {
            const entityValue = entity[columnData.entityAlias];
            if (undefined !== entityValue) {
                updateObject[columnData.sqlName] = entityValue;
            }
        }
        return updateObject;
    }
    mInsertOnAutoincrementWithNoMultipleReturning(entities, autoGeneratedColumn) {
        if (0 === entities.length) {
            return new Promise((resolve) => resolve());
        }
        return this
            ._dbConnection
            .transaction((transaction) => {
            const queries = new Array();
            for (const entity of entities) {
                queries.push(this
                    ._dbConnection
                    .returning(autoGeneratedColumn.sqlName)
                    .insert(this.buildKnexObject(this._model, entity))
                    .into(this._model.tableName)
                    .transacting(transaction));
            }
            Promise.all(queries)
                .then((values) => {
                return transaction.commit().then(() => {
                    for (let i = 0; i < entities.length; ++i) {
                        const value = values[i][0];
                        if (null != value) {
                            entities[i][autoGeneratedColumn.entityAlias] = value;
                        }
                    }
                });
            })
                .catch(transaction.rollback);
        });
    }
}
exports.SecondaryEntityManagerHelper = SecondaryEntityManagerHelper;
//# sourceMappingURL=SecondayEntityManagerHelper.js.map