"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ModelManager_1 = require("@antjs/ant-js/src/persistence/primary/ModelManager");
const AntSqlModel_1 = require("../../model/AntSqlModel");
const AntSqlSecondaryEntityManager_1 = require("../../persistence/secondary/AntSqlSecondaryEntityManager");
const RedisWrapper_1 = require("../persistence/primary/RedisWrapper");
const AntSqlModelManagerForTest_1 = require("./AntSqlModelManagerForTest");
const MAX_SAFE_TIMEOUT = Math.pow(2, 31) - 1;
const modelTestGen = (prefix) => new AntSqlModel_1.AntSqlModel('id', { prefix: prefix }, [{
        entityAlias: 'id',
        sqlName: 'id',
    }], prefix.replace(/\//g, '_'));
class AntSqlModelManagerTest {
    constructor(dbConnection, dbAlias) {
        this._dbConnection = dbConnection;
        this._declareName = AntSqlModelManagerTest.name + '/' + dbAlias;
        this._redisWrapper = new RedisWrapper_1.RedisWrapper();
    }
    performTests() {
        describe(this._declareName, () => {
            this._itMustCallModelManagerMethods();
            this._itMustGenerateAModelManager();
            this._itMustGenerateASecondaryEntityManager();
        });
    }
    _itMustCallModelManagerMethods() {
        const itsName = 'mustCallModelManagerMethods';
        const prefix = this._declareName + '/' + itsName + '/';
        it(itsName, async (done) => {
            const model = modelTestGen(prefix);
            const antModelManager = new AntSqlModelManagerForTest_1.AntSqlModelManagerForTest(model, new Map());
            antModelManager.config({
                knex: this._dbConnection,
                redis: this._redisWrapper.redis,
            });
            const modelManager = antModelManager.modelManager;
            const methodsToTest = [
                'insert',
                'mInsert',
            ];
            for (const methodToTest of methodsToTest) {
                spyOn(modelManager, methodToTest).and.returnValue(methodToTest);
            }
            const entity = { id: 0 };
            const [insertResult, mInsertResult,] = await Promise.all([
                antModelManager.insert(entity),
                antModelManager.mInsert([entity]),
            ]);
            const results = {
                insert: insertResult,
                mInsert: mInsertResult,
            };
            for (const methodToTest of methodsToTest) {
                expect(modelManager[methodToTest]).toHaveBeenCalled();
                expect(results[methodToTest]).toBe(methodToTest);
            }
            done();
        }, MAX_SAFE_TIMEOUT);
    }
    _itMustGenerateAModelManager() {
        const itsName = 'mustGenerateAModelManager';
        const prefix = this._declareName + '/' + itsName + '/';
        it(itsName, async (done) => {
            const model = modelTestGen(prefix);
            const config = {
                knex: this._dbConnection,
                redis: this._redisWrapper.redis,
            };
            const antModelManager = new AntSqlModelManagerForTest_1.AntSqlModelManagerForTest(model, new Map());
            const modelManager = antModelManager.generateModelManager(model, config);
            expect(modelManager instanceof ModelManager_1.ModelManager).toBe(true);
            done();
        }, MAX_SAFE_TIMEOUT);
    }
    _itMustGenerateASecondaryEntityManager() {
        const itsName = 'mustGenerateASecondaryEntityManager';
        const prefix = this._declareName + '/' + itsName + '/';
        it(itsName, async (done) => {
            const model = modelTestGen(prefix);
            const config = {
                knex: this._dbConnection,
                redis: this._redisWrapper.redis,
            };
            const antModelManager = new AntSqlModelManagerForTest_1.AntSqlModelManagerForTest(model, new Map());
            const secondaryEntityManager = antModelManager.generateSecondaryEntityManager(model, config);
            expect(secondaryEntityManager instanceof AntSqlSecondaryEntityManager_1.AntSqlSecondaryEntityManager).toBe(true);
            done();
        }, MAX_SAFE_TIMEOUT);
    }
}
exports.AntSqlModelManagerTest = AntSqlModelManagerTest;
//# sourceMappingURL=AntSqlModelManagerTest.js.map