"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DBConnectionWrapper_1 = require("../persistence/secondary/DBConnectionWrapper");
const DBTestManager_1 = require("../persistence/secondary/DBTestManager");
const DbServerAwaiter_1 = require("./DbServerAwaiter");
class DbServerAwaiterManager {
    constructor(millisPerRequest) {
        this._dbReadyAwaiters = new Map();
        this._dbTablesDeletedAwaiters = new Map();
        this._dbTestManager = new DBTestManager_1.DBTestManager();
        this._initializeAwaiters(millisPerRequest);
    }
    getReadyAwaiter(driverName) {
        return this._dbReadyAwaiters.get(driverName);
    }
    getTablesDeletedAwaiter(driverName) {
        return this._dbTablesDeletedAwaiters.get(driverName);
    }
    _createDBReadyPromise(config, dbServerAwaiter, testManager) {
        if (config.dbCreationOptions) {
            return dbServerAwaiter
                .awaitServer(config.dbCreationOptions.connection)
                .then(() => testManager.createDatabaseIfNotExists(config.dbCreationOptions.connection, config.dbCreationOptions.name));
        }
        else {
            const connection = config.connection;
            return dbServerAwaiter
                .awaitServer(connection);
        }
    }
    _initializeAwaiters(millisPerRequest) {
        const dbAwaiter = new DbServerAwaiter_1.DbServerAwaiter(millisPerRequest);
        const dbConnectionWrapper = new DBConnectionWrapper_1.DBConnectionWrapper();
        const dbTestManager = new DBTestManager_1.DBTestManager();
        for (const config of dbConnectionWrapper.config) {
            const connection = config.connection;
            const dbReadyPromise = this._createDBReadyPromise(config, dbAwaiter, dbTestManager);
            this._dbReadyAwaiters.set(connection.client.driverName, dbReadyPromise);
            const dbTablesDeletedAwaiter = dbReadyPromise
                .then(() => this._dbTestManager.deleteAllTables(connection));
            this._dbTablesDeletedAwaiters.set(connection.client.driverName, dbTablesDeletedAwaiter);
        }
    }
}
const millisPerRequest = 1000;
exports.dbServerAwaiterManager = new DbServerAwaiterManager(millisPerRequest);
//# sourceMappingURL=DbServerAwaiterManager.js.map