"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AntSqlModel_1 = require("../../model/AntSqlModel");
const AutoGenerationStrategyMode_1 = require("../../model/AutoGenerationStrategyMode");
const MAX_SAFE_TIMEOUT = Math.pow(2, 31) - 1;
class AntSqlModelTest {
    constructor() {
        this._declareName = AntSqlModelTest.name;
    }
    performTests() {
        describe(this._declareName, () => {
            this._itMustBeInitializable();
            this._itMustGetInitialValues();
            this._itMustGetAnAutogeneratedColumn();
            this._itMustNotAllowMultipleAutogeneratedColumns();
            this._itMustNotGetAnAutogeneratedColumn();
        });
    }
    _itMustBeInitializable() {
        const itsName = 'mustBeInitializable';
        it(itsName, async (done) => {
            expect(() => {
                new AntSqlModel_1.AntSqlModel('id', { prefix: 'somePrefix', suffix: 'someSuffix' }, [{
                        entityAlias: 'id',
                        sqlName: 'id',
                    }], 'ModelSqlTableName');
            }).not.toThrowError();
            done();
        }, MAX_SAFE_TIMEOUT);
    }
    _itMustGetInitialValues() {
        const itsName = 'mustGetInitialValues';
        it(itsName, async (done) => {
            const tableName = 'ModelSqlTableName';
            const model = new AntSqlModel_1.AntSqlModel('id', { prefix: 'somePrefix', suffix: 'someSuffix' }, [{
                    entityAlias: 'id',
                    sqlName: 'id',
                }], tableName);
            expect(model.tableName).toBe(tableName);
            done();
        }, MAX_SAFE_TIMEOUT);
    }
    _itMustGetAnAutogeneratedColumn() {
        const itsName = 'mustGetAnAutogeneratedColumn';
        it(itsName, async (done) => {
            const tableName = 'ModelSqlTableName';
            const column = {
                autoGenerationStrategy: AutoGenerationStrategyMode_1.AutoGeneratedStrategyMode.AutoIncrement,
                entityAlias: 'id',
                sqlName: 'id',
            };
            const model = new AntSqlModel_1.AntSqlModel('id', { prefix: 'somePrefix', suffix: 'someSuffix' }, [column], tableName);
            expect(model.getAutoGeneratedColumn()).toEqual(column);
            done();
        }, MAX_SAFE_TIMEOUT);
    }
    _itMustNotAllowMultipleAutogeneratedColumns() {
        const itsName = 'mustNotAllowMultipleAutogeneratedColumns';
        it(itsName, async (done) => {
            const tableName = 'ModelSqlTableName';
            const column1 = {
                autoGenerationStrategy: AutoGenerationStrategyMode_1.AutoGeneratedStrategyMode.AutoIncrement,
                entityAlias: 'id',
                sqlName: 'id',
            };
            const column2 = {
                autoGenerationStrategy: AutoGenerationStrategyMode_1.AutoGeneratedStrategyMode.AutoIncrement,
                entityAlias: 'name',
                sqlName: 'name',
            };
            expect(() => new AntSqlModel_1.AntSqlModel('id', { prefix: 'somePrefix', suffix: 'someSuffix' }, [column1, column2], tableName)).toThrowError();
            done();
        }, MAX_SAFE_TIMEOUT);
    }
    _itMustNotGetAnAutogeneratedColumn() {
        const itsName = 'mustNotGetAnAutogeneratedColumn';
        it(itsName, async (done) => {
            const tableName = 'ModelSqlTableName';
            const model = new AntSqlModel_1.AntSqlModel('id', { prefix: 'somePrefix', suffix: 'someSuffix' }, [{
                    entityAlias: 'id',
                    sqlName: 'id',
                }], tableName);
            expect(model.getAutoGeneratedColumn()).toBeNull();
            done();
        }, MAX_SAFE_TIMEOUT);
    }
}
exports.AntSqlModelTest = AntSqlModelTest;
//# sourceMappingURL=AntSqlModelTest.js.map