"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const crypto = require("crypto");
const AntSqlModel_1 = require("../../../model/AntSqlModel");
const SqlModelManager_1 = require("../../../persistence/primary/SqlModelManager");
const AntSqlSecondaryEntityManager_1 = require("../../../persistence/secondary/AntSqlSecondaryEntityManager");
const RedisWrapper_1 = require("./RedisWrapper");
const MAX_SAFE_TIMEOUT = Math.pow(2, 31) - 1;
const tableNameGenerator = (baseAlias) => 't_'
    + crypto
        .createHash('md5')
        .update(baseAlias)
        .digest('hex');
const modelGenerator = (keyGen) => {
    return new AntSqlModel_1.AntSqlModel('id', keyGen, [{ entityAlias: 'id', sqlName: 'id' }], (keyGen.prefix ? tableNameGenerator(keyGen.prefix) : '')
        + (keyGen.prefix && keyGen.suffix ? '_' : '')
        + (keyGen.suffix ? tableNameGenerator(keyGen.suffix) : ''));
};
class SqlModelManagerTest {
    constructor(dbConnection, dbAlias) {
        this._dbConnection = dbConnection;
        this._declareName = SqlModelManagerTest.name + '/' + dbAlias;
        this._redis = new RedisWrapper_1.RedisWrapper();
    }
    performTests() {
        describe(this._declareName, () => {
            this._itMustBeInitializable();
            this._itMustCallSecondaryEntityManagerMethods();
        });
    }
    _itMustBeInitializable() {
        const itsName = 'mustBeInitializable';
        const prefix = this._declareName + '/' + itsName + '/';
        it(itsName, async (done) => {
            const model = modelGenerator({ prefix: prefix });
            const secondaryEntityManager = new AntSqlSecondaryEntityManager_1.AntSqlSecondaryEntityManager(model, this._dbConnection);
            expect(() => {
                new SqlModelManager_1.SqlModelManager(model, this._redis.redis, secondaryEntityManager);
            }).not.toThrowError();
            done();
        }, MAX_SAFE_TIMEOUT);
    }
    _itMustCallSecondaryEntityManagerMethods() {
        const itsName = 'mustCallSecondaryEntityManagerMethods';
        const prefix = this._declareName + '/' + itsName + '/';
        it(itsName, async (done) => {
            const model = modelGenerator({ prefix: prefix });
            const secondaryEntityManager = new AntSqlSecondaryEntityManager_1.AntSqlSecondaryEntityManager(model, this._dbConnection);
            const sqlModelManager = new SqlModelManager_1.SqlModelManager(model, this._redis.redis, secondaryEntityManager);
            const methodsToTest = [
                'delete',
                'insert',
                'mDelete',
                'mInsert',
                'mUpdate',
                'update',
            ];
            for (const methodToTest of methodsToTest) {
                spyOn(secondaryEntityManager, methodToTest).and.returnValue(new Promise((resolve) => resolve(methodToTest)));
            }
            const entity = { id: 0 };
            await Promise.all([
                sqlModelManager.delete(entity.id),
                sqlModelManager.insert(entity),
                sqlModelManager.mDelete([entity.id]),
                sqlModelManager.mInsert([entity]),
                sqlModelManager.mUpdate([entity]),
                sqlModelManager.update(entity),
            ]);
            for (const methodToTest of methodsToTest) {
                expect(secondaryEntityManager[methodToTest]).toHaveBeenCalled();
            }
            done();
        }, MAX_SAFE_TIMEOUT);
    }
}
exports.SqlModelManagerTest = SqlModelManagerTest;
//# sourceMappingURL=SqlModelManagerTest.js.map