"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Knex = require("knex");
const KnexDriver_1 = require("../../../persistence/secondary/KnexDriver");
const fakeConnection = Knex({
    client: KnexDriver_1.KnexDriver.PG,
    connection: {
        database: 'fakedatabase',
        host: 'fake_host',
        password: 'fake_pw',
        user: 'fake_user',
    },
    version: '11.2',
});
const msSqlConnectionTestConfig = {
    connection: Knex({
        client: KnexDriver_1.KnexDriver.MSSQL,
        connection: {
            database: process.env.MS_DB,
            host: 'ant_db_mssql',
            password: process.env.MS_SA_PASSWORD,
            user: process.env.MS_SA_USER,
        },
    }),
    dbCreationOptions: {
        connection: Knex({
            client: KnexDriver_1.KnexDriver.MSSQL,
            connection: {
                host: 'ant_db_mssql',
                password: process.env.MS_SA_PASSWORD,
                user: process.env.MS_SA_USER,
            },
        }),
        name: process.env.MS_DB,
    },
};
const mySqlDbConnectionTestConfig = {
    connection: Knex({
        client: KnexDriver_1.KnexDriver.MYSQL,
        connection: {
            database: process.env.MYSQL_DB,
            host: 'ant_db_mysql',
            password: process.env.DB_PASSWORD,
            user: process.env.DB_USER,
        },
        version: '8.0.16',
    }),
};
const mySql2DbConnectionTestConfig = {
    connection: Knex({
        client: KnexDriver_1.KnexDriver.MYSQL2,
        connection: {
            database: process.env.MYSQL_2_DB,
            host: 'ant_db_mysql',
            password: process.env.DB_PASSWORD,
            user: process.env.DB_USER,
        },
        version: '8.0.16',
    }),
};
const postgreDbConnectionTestConfig = {
    connection: Knex({
        client: KnexDriver_1.KnexDriver.PG,
        connection: {
            database: process.env.PG_DB,
            host: 'ant_db_postgres',
            password: process.env.DB_PASSWORD,
            user: process.env.DB_USER,
        },
        version: '11.2',
    }),
};
const sqliteDbConnectionTestConfig = {
    connection: Knex({
        client: KnexDriver_1.KnexDriver.SQLITE3,
        connection: {
            filename: ':memory:',
        },
    }),
};
class DBConnectionWrapper {
    constructor() {
        this._fakeConnection = fakeConnection;
        this._msSqlDbConnectionConfig = msSqlConnectionTestConfig;
        this._mySqlDbConnectionConfig = mySqlDbConnectionTestConfig;
        this._mySql2DbConnectionConfig = mySql2DbConnectionTestConfig;
        this._postgreDbConnectionConfig = postgreDbConnectionTestConfig;
        this._sqliteDbConnectionTestConfig = sqliteDbConnectionTestConfig;
    }
    get config() {
        return [
            this._msSqlDbConnectionConfig,
            this._mySqlDbConnectionConfig,
            this._mySql2DbConnectionConfig,
            this._postgreDbConnectionConfig,
            this._sqliteDbConnectionTestConfig,
        ];
    }
    get fakeConnection() {
        return this._fakeConnection;
    }
    get msConfig() {
        return this._msSqlDbConnectionConfig;
    }
    get mySqlConfig() {
        return this._mySqlDbConnectionConfig;
    }
    get mySql2Config() {
        return this._mySql2DbConnectionConfig;
    }
    get pgConfig() {
        return this._postgreDbConnectionConfig;
    }
    get sqliteConfig() {
        return this._sqliteDbConnectionTestConfig;
    }
}
exports.DBConnectionWrapper = DBConnectionWrapper;
//# sourceMappingURL=DBConnectionWrapper.js.map