"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AntMySqlSecondaryEntityManager_1 = require("../../../persistence/secondary/AntMySqlSecondaryEntityManager");
const KnexDriver_1 = require("../../../persistence/secondary/KnexDriver");
const SecondayEntityManagerHelper_1 = require("../../../persistence/secondary/SecondayEntityManagerHelper");
const DbServerAwaiterManager_1 = require("../../await/DbServerAwaiterManager");
const AntSqlModelGenerator_1 = require("../../model/AntSqlModelGenerator");
const DBConnectionWrapper_1 = require("./DBConnectionWrapper");
const DBTestManager_1 = require("./DBTestManager");
const MAX_SAFE_TIMEOUT = Math.pow(2, 31) - 1;
const namedModelGenerator = (keyGen, autoGeneratedId = false) => AntSqlModelGenerator_1.modelGenerator(keyGen, ['name'], autoGeneratedId ? 'id' : null);
const tableGeneratorOtherColumns = { name: 'string' };
class SecondaryEntityManagerHelperTest {
    constructor() {
        this._dbConnectionWrapper = new DBConnectionWrapper_1.DBConnectionWrapper();
        this._dbTestManager = new DBTestManager_1.DBTestManager();
        this._declareName = SecondaryEntityManagerHelperTest.name;
    }
    performTests() {
        describe(this._declareName, () => {
            this._itMustBeInitializable();
            this._itMustInsertMultipleEntitiesOnAutoIncrementWithNoMultipleReturning();
            this._itMustInsertZeroEntitiesOnAutoIncrementWithNoMultipleReturning();
        });
    }
    _itMustBeInitializable() {
        const itsName = 'mustBeInitializable';
        it(itsName, async (done) => {
            expect(() => {
                new SecondayEntityManagerHelper_1.SecondaryEntityManagerHelper(null, null);
            }).not.toThrowError();
            done();
        }, MAX_SAFE_TIMEOUT);
    }
    _itMustInsertMultipleEntitiesOnAutoIncrementWithNoMultipleReturning() {
        const itsName = 'mustInsertMultipleEntitiesOnAutoIncrementWithNoMultipleReturning';
        const prefix = this._declareName + '/' + itsName + '/';
        it(itsName, async (done) => {
            await DbServerAwaiterManager_1.dbServerAwaiterManager.getTablesDeletedAwaiter(KnexDriver_1.KnexDriver.MYSQL);
            const model = namedModelGenerator({ prefix: prefix }, true);
            const entity = { id: undefined, name: 'name' };
            const entity2 = { id: undefined, name: 'name2' };
            await this._dbTestManager.createTable(this._dbConnectionWrapper.mySqlConfig.connection, model.tableName, { name: 'id', type: 'increments' }, tableGeneratorOtherColumns);
            const secondaryEntityManager = new AntMySqlSecondaryEntityManager_1.AntMySqlSecondaryEntityManager(model, this._dbConnectionWrapper.mySqlConfig.connection);
            const helper = new SecondayEntityManagerHelper_1.SecondaryEntityManagerHelper(model, this._dbConnectionWrapper.mySqlConfig.connection);
            await helper.mInsertOnAutoincrementWithNoMultipleReturning([entity, entity2], model.getAutoGeneratedColumn());
            const entityFound = await secondaryEntityManager.getById(entity.id);
            const entityFound2 = await secondaryEntityManager.getById(entity2.id);
            expect(typeof entityFound.id).toBe('number');
            expect(entityFound.name).toBe(entity.name);
            expect(typeof entityFound2.id).toBe('number');
            expect(entityFound2.name).toBe(entity2.name);
            done();
        }, MAX_SAFE_TIMEOUT);
    }
    _itMustInsertZeroEntitiesOnAutoIncrementWithNoMultipleReturning() {
        const itsName = 'mustInsertZeroEntitiesOnAutoIncrementWithNoMultipleReturning';
        const prefix = this._declareName + '/' + itsName + '/';
        it(itsName, async (done) => {
            await DbServerAwaiterManager_1.dbServerAwaiterManager.getTablesDeletedAwaiter(KnexDriver_1.KnexDriver.MYSQL);
            const model = namedModelGenerator({ prefix: prefix }, true);
            await this._dbTestManager.createTable(this._dbConnectionWrapper.mySqlConfig.connection, model.tableName, { name: 'id', type: 'increments' }, tableGeneratorOtherColumns);
            const helper = new SecondayEntityManagerHelper_1.SecondaryEntityManagerHelper(model, this._dbConnectionWrapper.mySqlConfig.connection);
            expectAsync(helper.mInsertOnAutoincrementWithNoMultipleReturning(new Array(), model.getAutoGeneratedColumn())).toBeResolved();
            done();
        }, MAX_SAFE_TIMEOUT);
    }
}
exports.SecondaryEntityManagerHelperTest = SecondaryEntityManagerHelperTest;
//# sourceMappingURL=SecondaryEntityManagerHelperTest.js.map